@@ -24,9 +24,10 @@ from glances.logger import logger
 
 try:
     from packaging.version import Version
+
     PACKAGING_IMPORT = True
 except Exception as e:
-    logger.error("Unable to import 'packaging' module ({}). Glances cannot check for updates.".format(e))
+    logger.warning("Unable to import 'packaging' module ({}). Glances cannot check for updates.".format(e))
     PACKAGING_IMPORT = False
 
 PYPI_API_URL = 'https://pypi.python.org/pypi/Glances/json'
@@ -48,10 +49,15 @@ class Outdated(object):
 
         # Set default value...
         self.data = {u'installed_version': __version__, u'latest_version': '0.0', u'refresh_date': datetime.now()}
-        # Read the configuration file
-        self.load_config(config)
+
+        # Disable update check if `packaging` is not installed
         if not PACKAGING_IMPORT:
             self.args.disable_check_update = True
+
+        # Read the configuration file only if update check is not explicitly disabled
+        if not self.args.disable_check_update:
+            self.load_config(config)
+
         logger.debug("Check Glances version up-to-date: {}".format(not self.args.disable_check_update))
 
         # And update !
