@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Sensors plugin."""
 
@@ -30,7 +20,10 @@ from glances.plugins.sensors.glances_hddtemp import Plugin as HddTempPlugin
 from glances.outputs.glances_unicode import unicode_message
 from glances.plugins.glances_plugin import GlancesPlugin
 
+SENSOR_TEMP_TYPE = 'temperature_core'
 SENSOR_TEMP_UNIT = 'C'
+
+SENSOR_FAN_TYPE = 'fan_speed'
 SENSOR_FAN_UNIT = 'R'
 
 
@@ -89,7 +82,7 @@ class Plugin(GlancesPlugin):
             stats = []
             # Get the temperature
             try:
-                temperature = self.__set_type(self.glances_grab_sensors.get('temperature_core'), 'temperature_core')
+                temperature = self.__set_type(self.glances_grab_sensors.get(SENSOR_TEMP_TYPE), SENSOR_TEMP_TYPE)
             except Exception as e:
                 logger.error("Cannot grab sensors temperatures (%s)" % e)
             else:
@@ -97,7 +90,7 @@ class Plugin(GlancesPlugin):
                 stats.extend(temperature)
             # Get the FAN speed
             try:
-                fan_speed = self.__set_type(self.glances_grab_sensors.get('fan_speed'), 'fan_speed')
+                fan_speed = self.__set_type(self.glances_grab_sensors.get(SENSOR_FAN_TYPE), SENSOR_FAN_TYPE)
             except Exception as e:
                 logger.error("Cannot grab FAN speed (%s)" % e)
             else:
@@ -124,30 +117,40 @@ class Plugin(GlancesPlugin):
             # Update stats using SNMP
             # No standard:
             # http://www.net-snmp.org/wiki/index.php/Net-SNMP_and_lm-sensors_on_Ubuntu_10.04
-
             pass
 
         # Global change on stats
         self.stats = self.get_init_value()
         for stat in stats:
             # Do not take hide stat into account
-            if self.is_hide(stat["label"].lower()):
+            if not self.is_display(stat["label"].lower()):
                 continue
             # Set the alias for each stat
-            alias = self.has_alias(stat["label"].lower())
-            if alias:
-                stat["label"] = alias
+            # alias = self.has_alias(stat["label"].lower())
+            # if alias:
+            #     stat["label"] = alias
+            stat["label"] = self.__get_alias(stat)
             # Update the stats
             self.stats.append(stat)
 
         return self.stats
 
+    def __get_alias(self, stats):
+        """Return the alias of the sensor."""
+        # Get the alias for each stat
+        if self.has_alias(stats["label"].lower()):
+            return self.has_alias(stats["label"].lower())
+        elif self.has_alias("{}_{}".format(stats["label"], stats["type"]).lower()):
+            return self.has_alias("{}_{}".format(stats["label"], stats["type"]).lower())
+        else:
+            return stats["label"]
+
     def __set_type(self, stats, sensor_type):
         """Set the plugin type.
 
         4 types of stats is possible in the sensors plugin:
-        - Core temperature: 'temperature_core'
-        - Fan speed: 'fan_speed'
+        - Core temperature: SENSOR_TEMP_TYPE
+        - Fan speed: SENSOR_FAN_TYPE
         - HDD temperature: 'temperature_hdd'
         - Battery capacity: 'battery'
         """
@@ -170,17 +173,22 @@ class Plugin(GlancesPlugin):
             if not i['value']:
                 continue
             # Alert processing
-            if i['type'] == 'temperature_core' and not self.is_limit('critical', stat_name=i['type']):
-                if i['critical'] is None:
-                    alert = 'DEFAULT'
-                elif i['value'] >= i['critical']:
-                    alert = 'CRITICAL'
-                elif i['warning'] is None:
-                    alert = 'DEFAULT'
-                elif i['value'] >= i['warning']:
-                    alert = 'WARNING'
+            if i['type'] == SENSOR_TEMP_TYPE:
+                if self.is_limit('critical', stat_name='sensors_temperature_' + i['label']):
+                    # By default use the thresholds configured in the glances.conf file (see #2058)
+                    alert = self.get_alert(current=i['value'], header='temperature_' + i['label'])
                 else:
-                    alert = 'OK'
+                    # Else use the system thresholds
+                    if i['critical'] is None:
+                        alert = 'DEFAULT'
+                    elif i['value'] >= i['critical']:
+                        alert = 'CRITICAL'
+                    elif i['warning'] is None:
+                        alert = 'DEFAULT'
+                    elif i['value'] >= i['warning']:
+                        alert = 'WARNING'
+                    else:
+                        alert = 'OK'
             elif i['type'] == 'battery':
                 alert = self.get_alert(current=100 - i['value'], header=i['type'])
             else:
@@ -189,7 +197,7 @@ class Plugin(GlancesPlugin):
             self.views[i[self.get_key()]]['value']['decoration'] = alert
 
     def battery_trend(self, stats):
-        """Return the trend characterr for the battery"""
+        """Return the trend character for the battery"""
         if 'status' not in stats:
             return ''
         if stats['status'].startswith('Charg'):
@@ -231,7 +239,7 @@ class Plugin(GlancesPlugin):
                     self.curse_add_line(msg, self.get_views(item=i[self.get_key()], key='value', option='decoration'))
                 )
             else:
-                if args.fahrenheit and i['type'] != 'battery' and i['type'] != 'fan_speed':
+                if args.fahrenheit and i['type'] != 'battery' and i['type'] != SENSOR_FAN_TYPE:
                     trend = ''
                     value = to_fahrenheit(i['value'])
                     unit = 'F'
@@ -323,32 +331,34 @@ class GlancesGrabSensors(object):
         else:
             return ret
         for chip_name, chip in iteritems(input_list):
-            i = 1
-            for feature in chip:
+            label_index = 1
+            for chip_name_index, feature in enumerate(chip):
                 sensors_current = {}
                 # Sensor name
                 if feature.label == '':
-                    sensors_current['label'] = chip_name + ' ' + str(i)
+                    sensors_current['label'] = chip_name + ' ' + str(chip_name_index)
+                elif feature.label in [i['label'] for i in ret]:
+                    sensors_current['label'] = feature.label + ' ' + str(label_index)
+                    label_index += 1
                 else:
                     sensors_current['label'] = feature.label
                 # Sensors value, limit and unit
-                sensors_current['value'] = int(getattr(feature, 'current', 0) if getattr(feature, 'current', 0) else 0)
-                warning = getattr(feature, 'high', None)
-                sensors_current['warning'] = int(warning) if warning is not None else None
-                critical = getattr(feature, 'critical', None)
-                sensors_current['critical'] = int(critical) if critical is not None else None
                 sensors_current['unit'] = type
+                sensors_current['value'] = int(getattr(feature, 'current', 0) if getattr(feature, 'current', 0) else 0)
+                system_warning = getattr(feature, 'high', None)
+                system_critical = getattr(feature, 'critical', None)
+                sensors_current['warning'] = int(system_warning) if system_warning is not None else None
+                sensors_current['critical'] = int(system_critical) if system_critical is not None else None
                 # Add sensor to the list
                 ret.append(sensors_current)
-                i += 1
         return ret
 
-    def get(self, sensor_type='temperature_core'):
+    def get(self, sensor_type=SENSOR_TEMP_TYPE):
         """Get sensors list."""
         self.__update__()
-        if sensor_type == 'temperature_core':
+        if sensor_type == SENSOR_TEMP_TYPE:
             ret = [s for s in self.sensors_list if s['unit'] == SENSOR_TEMP_UNIT]
-        elif sensor_type == 'fan_speed':
+        elif sensor_type == SENSOR_FAN_TYPE:
             ret = [s for s in self.sensors_list if s['unit'] == SENSOR_FAN_UNIT]
         else:
             # Unknown type
