@@ -90,11 +90,9 @@ class Plugin(GlancesPlugin):
                 except InterfaceError as e:
                     # Not a Wifi interface
                     logger.debug("WIFI plugin: Scan InterfaceError ({})".format(e))
-                    pass
                 except Exception as e:
                     # Other error
                     logger.debug("WIFI plugin: Can not grab cell stats ({})".format(e))
-                    pass
                 else:
                     for wifi_cell in wifi_cells:
                         hotspot = {
@@ -190,7 +188,9 @@ class Plugin(GlancesPlugin):
             # Add the new hotspot to the message
             msg = '{:{width}}'.format(nativestr(hotspot_name), width=if_name_max_width)
             ret.append(self.curse_add_line(msg))
-            msg = '{:>7}'.format(i['signal'], width=if_name_max_width)
+            msg = '{:>7}'.format(
+                i['signal'],
+            )
             ret.append(
                 self.curse_add_line(msg, self.get_views(item=i[self.get_key()], key='signal', option='decoration'))
             )
