@@ -110,7 +110,7 @@ class GlancesStats(object):
             # on the console but do not crash
             logger.critical("Error while initializing the {} plugin ({})".format(name, e))
             logger.error(traceback.format_exc())
-            # An error occure, disable the plugin
+            # An error occurred, disable the plugin
             if args is not None:
                 setattr(args, 'disable_' + name, False)
         else:
@@ -118,7 +118,7 @@ class GlancesStats(object):
             if args is not None:
                 # If the all key is set in the disable_plugin option then look in the enable_plugin option
                 if getattr(args, 'disable_all', False):
-                    logger.info('%s => %s', name, getattr(args, 'enable_' + name, False))
+                    logger.debug('%s => %s', name, getattr(args, 'enable_' + name, False))
                     setattr(args, 'disable_' + name, not getattr(args, 'enable_' + name, False))
                 else:
                     setattr(args, 'disable_' + name, getattr(args, 'disable_' + name, False))
@@ -253,8 +253,8 @@ class GlancesStats(object):
         if plugin_list is provided, only export stats of given plugin (list)
         """
         if plugin_list is None:
-            # All plugins should be exported
-            plugin_list = self._plugins
+            # All enabled plugins should be exported
+            plugin_list = self.getPluginsList()
         return [self._plugins[p].get_export() for p in self._plugins]
 
     def getAllExportsAsDict(self, plugin_list=None):
@@ -264,13 +264,20 @@ class GlancesStats(object):
         if plugin_list is provided, only export stats of given plugin (list)
         """
         if plugin_list is None:
-            # All plugins should be exported
-            plugin_list = self._plugins
+            # All enabled plugins should be exported
+            plugin_list = self.getPluginsList()
         return {p: self._plugins[p].get_export() for p in plugin_list}
 
-    def getAllLimits(self):
-        """Return the plugins limits list."""
-        return [self._plugins[p].limits for p in self._plugins]
+    def getAllLimits(self, plugin_list=None):
+        """Return the plugins limits list.
+
+        Default behavior is to export all the limits
+        if plugin_list is provided, only export limits of given plugin (list)
+        """
+        if plugin_list is None:
+            # All enabled plugins should be exported
+            plugin_list = self.getPluginsList()
+        return [self._plugins[p].limits for p in plugin_list]
 
     def getAllLimitsAsDict(self, plugin_list=None):
         """Return all the stats limits (dict).
@@ -279,8 +286,8 @@ class GlancesStats(object):
         if plugin_list is provided, only export limits of given plugin (list)
         """
         if plugin_list is None:
-            # All plugins should be exported
-            plugin_list = self._plugins
+            # All enabled plugins should be exported
+            plugin_list = self.getPluginsList()
         return {p: self._plugins[p].limits for p in plugin_list}
 
     def getAllViews(self):
